/*
 * private_mib_bt6709.c
 *
 *  Created on: 03.10.2018
 *      Author: balbekova
 */


#if HARDWARE_BT6711 || HARDWARE_BT6711_V1 || HARDWARE_BT6721
#include "stm32f4xx.h"
#include "private_mib.h"
#include "parameters.h"
#include "settings_api.h"
#include "log.h"
#include "megatec.h"
#include "control_symbol.h"
#include "sntp_api.h"
#include "web_params_api.h"
#include "hal.h"

#include "FreeRTOS.h"
#include "task.h"

#include <ctype.h>

#ifdef PRINTF_STDLIB
#include <stdio.h>
#endif
#ifdef PRINTF_CUSTOM
#include "tinystdio.h"
#endif

#include "lwip/apps/snmp_scalar.h"
#include "lwip/apps/snmp.h"
//#include "snmp_core.h"

#define MUL100          100
#define MUL10           10

extern struct snmp_mib mib2;

/**
  * @brief  Общая структура настроек
  */
extern SETTINGS_t sSettings;


static s16_t signal_get_value(struct snmp_node_instance *instance, void *value);
static snmp_err_t signal_set_value(struct snmp_node_instance *instance, u16_t len, void *value);
static snmp_err_t signal_set_test(struct snmp_node_instance *instance, u16_t len, void *value);

/* signal .1.3.6.1.4.1.41752.911.11.1.64  */
static const struct snmp_scalar_node signal64 = SNMP_SCALAR_CREATE_NODE_READONLY(64, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.63  */
static const struct snmp_scalar_node signal63 = SNMP_SCALAR_CREATE_NODE_READONLY(63, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.62  */
static const struct snmp_scalar_node signal62 = SNMP_SCALAR_CREATE_NODE_READONLY(62, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.61  */
static const struct snmp_scalar_node signal61 = SNMP_SCALAR_CREATE_NODE(61, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.60  */
static const struct snmp_scalar_node signal60 = SNMP_SCALAR_CREATE_NODE(60, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.59  */
static const struct snmp_scalar_node signal59 = SNMP_SCALAR_CREATE_NODE(59, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.58  */
static const struct snmp_scalar_node signal58 = SNMP_SCALAR_CREATE_NODE(58, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.57  */
static const struct snmp_scalar_node signal57 = SNMP_SCALAR_CREATE_NODE(57, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.56  */
static const struct snmp_scalar_node signal56 = SNMP_SCALAR_CREATE_NODE(56, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.55  */
static const struct snmp_scalar_node signal55 = SNMP_SCALAR_CREATE_NODE(55, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.54  */
static const struct snmp_scalar_node signal54 =SNMP_SCALAR_CREATE_NODE_READONLY(54, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.53  */
static const struct snmp_scalar_node signal53 = SNMP_SCALAR_CREATE_NODE(53, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.52  */
static const struct snmp_scalar_node signal52 = SNMP_SCALAR_CREATE_NODE(52, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.51  */
static const struct snmp_scalar_node signal51 = SNMP_SCALAR_CREATE_NODE_READONLY(51, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.50  */
static const struct snmp_scalar_node signal50 = SNMP_SCALAR_CREATE_NODE(50, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.49  */
static const struct snmp_scalar_node signal49 = SNMP_SCALAR_CREATE_NODE(49, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.48  */
static const struct snmp_scalar_node signal48 = SNMP_SCALAR_CREATE_NODE(48, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.47  */
static const struct snmp_scalar_node signal47 = SNMP_SCALAR_CREATE_NODE(47, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.46  */
static const struct snmp_scalar_node signal46 = SNMP_SCALAR_CREATE_NODE(46, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.45  */
static const struct snmp_scalar_node signal45 = SNMP_SCALAR_CREATE_NODE(45, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.44  */
static const struct snmp_scalar_node signal44 = SNMP_SCALAR_CREATE_NODE(44, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.43  */
static const struct snmp_scalar_node signal43 = SNMP_SCALAR_CREATE_NODE(43, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.42  */
static const struct snmp_scalar_node signal42 = SNMP_SCALAR_CREATE_NODE(42, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.41  */
static const struct snmp_scalar_node signal41 = SNMP_SCALAR_CREATE_NODE(41, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.40  */
static const struct snmp_scalar_node signal40 = SNMP_SCALAR_CREATE_NODE(40, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.39  */
static const struct snmp_scalar_node signal39 = SNMP_SCALAR_CREATE_NODE(39, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.38  */
static const struct snmp_scalar_node signal38 = SNMP_SCALAR_CREATE_NODE(38, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.37  */
static const struct snmp_scalar_node signal37 = SNMP_SCALAR_CREATE_NODE(37, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.36  */
static const struct snmp_scalar_node signal36 = SNMP_SCALAR_CREATE_NODE(36, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.35  */
static const struct snmp_scalar_node signal35 = SNMP_SCALAR_CREATE_NODE(35, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.10.1.34  */
static const struct snmp_scalar_node signal34 = SNMP_SCALAR_CREATE_NODE(34, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.33  */
static const struct snmp_scalar_node signal33 = SNMP_SCALAR_CREATE_NODE(33, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.32  */
static const struct snmp_scalar_node signal32 = SNMP_SCALAR_CREATE_NODE(32, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.31  */
static const struct snmp_scalar_node signal31 = SNMP_SCALAR_CREATE_NODE_READONLY(31, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);
/* signal .1.3.6.1.4.1.41752.911.11.1.30  */
static const struct snmp_scalar_node signal30 = SNMP_SCALAR_CREATE_NODE_READONLY(30, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.29  */
static const struct snmp_scalar_node signal29 = SNMP_SCALAR_CREATE_NODE_READONLY(29, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.28  */
static const struct snmp_scalar_node signal28 =SNMP_SCALAR_CREATE_NODE_READONLY(28, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.27  */
static const struct snmp_scalar_node signal27 = SNMP_SCALAR_CREATE_NODE_READONLY(27, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.26  */
static const struct snmp_scalar_node signal26 = SNMP_SCALAR_CREATE_NODE(26, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.25  */
static const struct snmp_scalar_node signal25 = SNMP_SCALAR_CREATE_NODE(25, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.24  */
static const struct snmp_scalar_node signal24 = SNMP_SCALAR_CREATE_NODE(24, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.23  */
static const struct snmp_scalar_node signal23 = SNMP_SCALAR_CREATE_NODE(23, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.22  */
static const struct snmp_scalar_node signal22 = SNMP_SCALAR_CREATE_NODE(22, SNMP_NODE_INSTANCE_READ_WRITE,
        SNMP_ASN1_TYPE_OCTET_STRING, signal_get_value, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.21  */
static const struct snmp_scalar_node signal21 = SNMP_SCALAR_CREATE_NODE_READONLY(21, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.20  */
static const struct snmp_scalar_node signal20 = SNMP_SCALAR_CREATE_NODE_READONLY(20, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.19  */
static const struct snmp_scalar_node signal19 = SNMP_SCALAR_CREATE_NODE_READONLY(19, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.18  */
static const struct snmp_scalar_node signal18 = SNMP_SCALAR_CREATE_NODE_READONLY(18, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.17  */
static const struct snmp_scalar_node signal17 = SNMP_SCALAR_CREATE_NODE_READONLY(17, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.16  */
static const struct snmp_scalar_node signal16 = SNMP_SCALAR_CREATE_NODE_READONLY(16, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.15  */
static const struct snmp_scalar_node signal15 = SNMP_SCALAR_CREATE_NODE_READONLY(15, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.14  */
static const struct snmp_scalar_node signal14 = SNMP_SCALAR_CREATE_NODE_READONLY(14, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.13  */
static const struct snmp_scalar_node signal13 = SNMP_SCALAR_CREATE_NODE_READONLY(13, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.12  */
static const struct snmp_scalar_node signal12 = SNMP_SCALAR_CREATE_NODE_READONLY(12, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.11  */
static const struct snmp_scalar_node signal11 = SNMP_SCALAR_CREATE_NODE_READONLY(11, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.10  */
static const struct snmp_scalar_node signal10 = SNMP_SCALAR_CREATE_NODE_READONLY(10, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.9  */
static const struct snmp_scalar_node signal9 = SNMP_SCALAR_CREATE_NODE_READONLY(9, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.8  */
static const struct snmp_scalar_node signal8 = SNMP_SCALAR_CREATE_NODE(8, SNMP_NODE_INSTANCE_WRITE_ONLY,
        SNMP_ASN1_TYPE_OCTET_STRING, NULL, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.7  */
static const struct snmp_scalar_node signal7 = SNMP_SCALAR_CREATE_NODE(7, SNMP_NODE_INSTANCE_WRITE_ONLY,
        SNMP_ASN1_TYPE_INTEGER, NULL, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.6  */
static const struct snmp_scalar_node signal6 = SNMP_SCALAR_CREATE_NODE_READONLY(6, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.5  */
static const struct snmp_scalar_node signal5 = SNMP_SCALAR_CREATE_NODE_READONLY(5, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.4  */
static const struct snmp_scalar_node signal4 = SNMP_SCALAR_CREATE_NODE_READONLY(4, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.3  */
static const struct snmp_scalar_node signal3 = SNMP_SCALAR_CREATE_NODE(3, SNMP_NODE_INSTANCE_WRITE_ONLY,
        SNMP_ASN1_TYPE_INTEGER, NULL, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.2  */
static const struct snmp_scalar_node signal2 = SNMP_SCALAR_CREATE_NODE(2, SNMP_NODE_INSTANCE_WRITE_ONLY,
        SNMP_ASN1_TYPE_INTEGER, NULL, signal_set_test, signal_set_value);

/* signal .1.3.6.1.4.1.41752.911.11.1.1  */
static const struct snmp_scalar_node signal1 = SNMP_SCALAR_CREATE_NODE_READONLY(1, SNMP_ASN1_TYPE_OCTET_STRING,
        signal_get_value);


// signals .1.3.6.1.4.1.41752.911.11.1
static const struct snmp_node *const signals_nodes[] = {
    &signal1.node.node,
    &signal2.node.node,
    &signal3.node.node,
    &signal4.node.node,
    &signal5.node.node,
    &signal6.node.node,
    &signal7.node.node,
    &signal8.node.node,
    &signal9.node.node,
    &signal10.node.node,
    &signal11.node.node,
    &signal12.node.node,
    &signal13.node.node,
    &signal14.node.node,
    &signal15.node.node,
    &signal16.node.node,
    &signal17.node.node,
    &signal18.node.node,
    &signal19.node.node,
    &signal20.node.node,
    &signal21.node.node,
    &signal22.node.node,
    &signal23.node.node,
    &signal24.node.node,
    &signal25.node.node,
    &signal26.node.node,
    &signal27.node.node,
    &signal28.node.node,
    &signal29.node.node,
    &signal30.node.node,
    &signal31.node.node,
    &signal32.node.node,
    &signal33.node.node,
    &signal34.node.node,
    &signal35.node.node,
    &signal36.node.node,
    &signal37.node.node,
    &signal38.node.node,
    &signal39.node.node,
    &signal40.node.node,
    &signal41.node.node,
    &signal42.node.node,
    &signal43.node.node,
    &signal44.node.node,
    &signal45.node.node,
    &signal46.node.node,
    &signal47.node.node,
    &signal48.node.node,
    &signal49.node.node,
    &signal50.node.node,
    &signal51.node.node,
    &signal52.node.node,
    &signal53.node.node,
    &signal54.node.node,
    &signal55.node.node,
    &signal56.node.node,
    &signal57.node.node,
    &signal58.node.node,
    &signal59.node.node,
    &signal60.node.node,
    &signal61.node.node,
    &signal62.node.node,
    &signal63.node.node,
    &signal64.node.node,
};
static const struct snmp_tree_node signals_node = SNMP_CREATE_TREE_NODE(1, signals_nodes);

// bt_6703 .1.3.6.1.4.1.41752.911.11
static const struct snmp_node *const bt6711_nodes[] = {
    &signals_node.node
};
static const struct snmp_tree_node bt6711_node = SNMP_CREATE_TREE_NODE(SNMP_DEV_ROOT_OID, bt6711_nodes);

// swt .1.3.6.1.4.1.41752.911
static const struct snmp_node *const swt_nodes[] = {
    &bt6711_node.node
};
static const struct snmp_tree_node swt_node = SNMP_CREATE_TREE_NODE(911, swt_nodes);

// rotek .1.3.6.1.4.1.41752
static const struct snmp_node *const rotek_nodes[] = {
    &swt_node.node
};
static const struct snmp_tree_node rotek_node = SNMP_CREATE_TREE_NODE(41752, rotek_nodes);

// enterprises .1.3.6.1.4.1
static const struct snmp_node *const enterprises_nodes[] = {
    &rotek_node.node
};
static const struct snmp_tree_node enterprises_node = SNMP_CREATE_TREE_NODE(1, enterprises_nodes);

// private .1.3.6.1.4
static const struct snmp_node *const private_nodes[] = {
    &enterprises_node.node
};
static const struct snmp_tree_node private_root = SNMP_CREATE_TREE_NODE(0, private_nodes);

static const u32_t prvmib_base_oid[] = { 1, 3, 6, 1, 4 };
static const struct snmp_mib private_mib = SNMP_MIB_CREATE(prvmib_base_oid, &private_root.node);




void lwip_privmib_init(void)
{
    static const struct snmp_mib *my_snmp_mibs[] = {&mib2, &private_mib};

    snmp_set_mibs(my_snmp_mibs, LWIP_ARRAYSIZE(my_snmp_mibs));
}



uint32_t check_netsettings(char *addr, uint8_t len)
{
    uint32_t val = 0;
    uint8_t i, j;
    uint8_t cnt_dot = 0;
    uint8_t digit = 0;

    uint8_t c = *addr;

    for (j = 0; j <= len; j ++) {
        if (isdigit(c)) {
            val = (val * 10) + (int)(c - '0');
        } else if (c == '.' || c == 0) {
            if (val > 0xff) {
                return 0;
            }
            cnt_dot ++;
            val = 0;
        } else {
            return 0;
        }
        c = *++addr;
    }

    if (cnt_dot != 4) {
        return 0;
    }
    return 1;
}

static s16_t signal_get_value(struct snmp_node_instance *instance, void *value)
{
    u8_t *paramStr = (u8_t *)value;
    s32_t *paramInt = (u8_t*)value;
    u8_t paramLength = 0;
    float val = 0;
    int32_t int_val = 0;
    u32_t oid = instance->node->oid; // id сигнала

    switch (oid) {
        case 1: /* FWVersion */
            GetVersionStr((char *)paramStr, &paramLength);
            break;
        case 4: /* UPSModel*/
            GetUPSModelStr((char *)paramStr, &paramLength);
            break;
        case 5: /* UPSSerial*/
            GetUPSSerialStr((char *)paramStr, &paramLength);
            break;
        case 6: /* UPSVersion*/
            GetUPSVersionStr((char *)paramStr, &paramLength);
            break;
        case 9: /* IntTemp */
            GetInternalTempStr((char *)paramStr, &paramLength);
            break;
        case 10: /* InFreq */
            GetInputFreqStr((char *)paramStr, &paramLength);
            break;
        case 11: /* InVoltVAC */
            GetInputVoltageStr((char *)paramStr, &paramLength);
            break;
        case 12: /* OutVoltVAC */
            GetOutputVoltageStr((char *)paramStr, &paramLength);
            break;
        case 13: /* Power */
            GetPowerStr((char *)paramStr, &paramLength);
            break;
        case 14: /* BatCap */
            GetBatCapacityStr((char *)paramStr, &paramLength);
            break;
        case 15: /* BatTime */
            GetRuntimeStr((char *)paramStr, &paramLength);
            break;
        case 16: /* ConnectMonitor */
            GetConnectMonitorStr((char *)paramStr, &paramLength);
            break;
        case 17: /* Alarms */
            GetAlarmStr((char *)paramStr, &paramLength);
            break;
         case 18: /* InputCurrent */
            GetInputCurrentStr((char *)paramStr, &paramLength);
            break;
        case 19: /* OutputCurrent */
            GetOutputCurrentStr((char *)paramStr, &paramLength);
            break;
        case 20: /* UPS mode */
            GetModeStr((char *)paramStr, &paramLength);
            break;
        case 21: /* VoltageAKB */
            GetVoltageAKBtStr((char *)paramStr, &paramLength);
            break;
        case 22: /* IP server1 (traps) */
            GetManagerIp((char *)paramStr, &paramLength);
            break;
        case 23: /* IP server2 (traps) */
            GetManagerIp2((char *)paramStr, &paramLength);
            break;
        case 24: /* IP server3 (traps) */
            GetManagerIp3((char *)paramStr, &paramLength);
            break;
        case 25: /* IP server4 (traps) */
            GetManagerIp4((char *)paramStr, &paramLength);
            break;
        case 26: /* IP server5 (traps) */
            GetManagerIp5((char *)paramStr, &paramLength);
            break;
        case 27: /* WhiteList range 1 */
            GetWhiteListSTR((char *)paramStr, &paramLength, 0);
            break;
        case 28: /* WhiteList range 2 */
            GetWhiteListSTR((char *)paramStr, &paramLength, 1);
            break;
        case 29: /* WhiteList range 3 */
            GetWhiteListSTR((char *)paramStr, &paramLength, 2);
            break;
        case 30: /* WhiteList range 4 */
            GetWhiteListSTR((char *)paramStr, &paramLength, 3);
            break;
        case 31: /* WhiteList range 5 */
            GetWhiteListSTR((char *)paramStr, &paramLength, 4);
            break;
        case 32: /* UPSVoltCellMin */
            GetUPSVoltCellMinStr((char *)paramStr, &paramLength);
            break;
        case 33: /* UPSVoltCellMax */
            GetUPSVoltCellMaxStr((char *)paramStr, &paramLength);
            break;
        case 34: /*  VoltageAKBNominal*/
            GetVoltageAKBNominalStr((char *)paramStr, &paramLength);
            break;
        case 35: /*  CapacityNominalAKB*/
            GetCapacityNominalAKBStr((char *)paramStr, &paramLength);
            break;
        case 36: /*  UPSFullPower*/
            GetUPSPowerStr((char *)paramStr, &paramLength);
            break;
        case 37: /* VACAlarmHighRange */
            GetVACAlarmHighRangeStr((char *)paramStr, &paramLength);
            break;
        case 38: /* VACAlarmLowRange */
            GetVACAlarmLowRangeStr((char *)paramStr, &paramLength);
            break;
        case 39: /* VACAlarmHistRange */
            GetVACAlarmHisteStr((char *)paramStr, &paramLength);
            break;
         case 40: /* VACInAlarmHighRange */
            GetVACInputAlarmHighRangeStr((char *)paramStr, &paramLength);
            break;
        case 41: /* VACInAlarmLowRange */
            GetVACInputAlarmLowRangeStr((char *)paramStr, &paramLength);
            break;
        case 42: /* VACInAlarmHistRange */
            GetVACinputAlarmHisteStr((char *)paramStr, &paramLength);
            break;
        case 43: /* TemperatureAlarmHighRange */
            GetTemperatureAlarmHighRangeStr((char *)paramStr, &paramLength);
            break;
        case 44: /* TemperatureAlarmLowRange */
            GetTemperatureAlarmLowRangeStr((char *)paramStr, &paramLength);
            break;
        case 45: /* TemperatureAlarmHistRange */
            GetTemperatureAlarmHisteStr((char *)paramStr, &paramLength);
            break;
        case 46: /* LoadAlarmHighRange */
            GetLoadAlarmHighRangeStr((char *)paramStr, &paramLength);
            break;
        case 47: /* LoadAlarmHistRange */
            GetLoadAlarmHisteStr((char *)paramStr, &paramLength);
            break;
        case 48: /* SntpTimeZone */
            GetSntpTimeZoneStr((char *)paramStr, &paramLength);
            break;
        case 49: /* SntpState */
            GetSntpStateStr((char *)paramStr, &paramLength);
            break;
        case 50: /* SntpServerIp */
            GetSntpServerIpStr((char *)paramStr, &paramLength);
            break;
        case 51: /* SntpLastData */
            GetSntpLastDataStr((char *)paramStr, &paramLength);
            break;
        case 52: /* Date */
            GetDateStr((char *)paramStr, &paramLength);
            break;
        case 53: /* Time */
            GetTimeStr((char *)paramStr, &paramLength);
            break;
        case 54: /* AKBTimeWork */
            GetAKBWorktimeStr((char *)paramStr, &paramLength);
            break;
        case 55: /* syslogEnable */
            GetSyslogEnable((char *)paramStr, &paramLength);
            break;
         case 56: /* syslogServerIP */
            GetSyslogServer((char *)paramStr, &paramLength);
            break;
        case 57: /* syslogServerPort */
            GetSyslogPort((char *)paramStr, &paramLength);
            break;
        case 58: /* radiusEnable */
            GetRDSEnableStateStr((char *)paramStr, &paramLength);
            break;
         case 59: /* radiusServerIP */
            GetRDSIpStr((char *)paramStr, &paramLength);
            break;
        case 60: /* radiusServerPort */
            GetRDSPortStr((char *)paramStr, &paramLength);
            break;
        case 61: /* radiusServerPWD */
            GetRDSPasswordkStr((char *)paramStr, &paramLength);
            break;
        case 62: /* ControllerModel*/
            GetSerialNumberStr((char *)paramStr, &paramLength);
            break;
        case 63: /*  LoadAKBMode */
            GetLoadAKBModeStr((char *)paramStr, &paramLength);
            break;
        case 64: /*  DataFormatCheckLoad */
            GetDataFormatCheckLoadStr((char *)paramStr, &paramLength);
            break;
        default:
            break;
    }

    return paramLength;

}

static snmp_err_t signal_set_value(struct snmp_node_instance *instance, u16_t len, void *value)
{

    u32_t oid = instance->node->oid; // id сигнала
    char *val_string;
    char str[20];
    int8_t res = 0;
    s32_t val;
    float setVal;
    bool enable_old_sntp;

    memset(str, 0, 20);

    switch (oid) {
        case 2: /* RestoreSignal */
            val = *(s32_t *)value;
            if (val == 1) {
                //    SNMP_SendUserTrap(DEVICE_RESTORED);
                log_event_data(LOG_SYSTEM_DEFCONFIG, "Администратор");
                vTaskDelay(500);
                SETTINGS_SetPartDefault();
                SETTINGS_Save();
            }
            break;
        case 3: /* RebootSignal */
            val = *(s32_t *)value;
            if (val == 1) {
                HTTP_StartResetTask(false);
            }
            break;
        case 7: /* BatTest */
            val = *(s32_t *)value;
            if (val == 0) {
                res = ups_metac_service_pdu(ups_cancel_test);
                if (res == 1) {
                    log_event_data(LOG_TEST_UPS, "Администратор (Останов)");
                }
            } else if (val > 0 && val < 100) {
                TimeParam = val;
                res = ups_metac_service_pdu(ups_test_time);
                set_act_source(SNMP_ACT);
            } else if (val == 100) {
                res = ups_metac_service_pdu(ups_test_10sec);
                set_act_source(SNMP_ACT);
            } else if (val == 999) {
                res = ups_metac_service_pdu(ups_test_low_bat);
                set_act_source(SNMP_ACT);
            }
            break;
        case 8: /* Shutdown UPS */
            val_string = (char *)value;
            float shtdn_val = atof(val_string);
            if (shtdn_val == 0) {
                res = ups_metac_service_pdu(ups_cancel_shut_down);
                if (res == 1) {
                    log_event_data(LOG_SHUTDOWN_UPS, "Администратор (Останов)");
                }
            } else {
                TimeParamFloat = shtdn_val;
                res = ups_metac_service_pdu(ups_shutdown);
                if (res == 1) {
                    log_event_data(LOG_SHUTDOWN_UPS, "Администратор");
                }
            }
            break;
        case 22:
            val_string = (char *)value;
            SetManagerIp(val_string);
            break;
        case 23:
            val_string = (char *)value;
            SetManagerIp2(val_string);
            break;
        case 24:
            val_string = (char *)value;
            SetManagerIp3(val_string);
            break;
        case 25:
            val_string = (char *)value;
            SetManagerIp4(val_string);
            break;
        case 26:
            val_string = (char *)value;
            SetManagerIp5(val_string);
            break;
        case 32:
            val_string = (char *)value;
            SetUPSVoltCellMinStr(val_string);
            break;
        case 33:
            val_string = (char *)value;
            SetUPSVoltCellMaxStr(val_string);
            break;
        case 34:
            val_string = (char *)value;
            SetVoltageAKBNominalStr(val_string);
            break;
        case 35:
            val_string = (char *)value;
            SetCapacityNominalAKBStr(val_string);
            break;
        case 36:
            val_string = (char *)value;
            SetUPSPowerStr(val_string);
            break;
        case 37:
            val_string = (char *)value;
            SetVACAlarmHighRangeStr(val_string);
            break;
        case 38:
            val_string = (char *)value;
            SetVACAlarmLowRangeStr(val_string);
            break;
        case 39:
            val_string = (char *)value;
            SetVACAlarmHisteStr(val_string);
            break;
        case 40:
            val_string = (char *)value;
            SetVACInputAlarmHighRangeStr(val_string);
            break;
        case 41:
            val_string = (char *)value;
            SetVACInputAlarmLowRangeStr(val_string);
            break;
        case 42:
            val_string = (char *)value;
            SetVACinputAlarmHisteStr(val_string);
            break;
        case 43:
            val_string = (char *)value;
            SetTemperatureAlarmHighRangeStr(val_string);
            break;
        case 44:
            val_string = (char *)value;
            SetTemperatureAlarmLowRangeStr(val_string);
            break;
        case 45:
            val_string = (char *)value;
            SetTemperatureAlarmHisteStr(val_string);
            break;
        case 46:
            val_string = (char *)value;
            SetLoadAlarmHighRangeStr(val_string);
            break;
        case 47:
            val_string = (char *)value;
            SetLoadAlarmHistStr(val_string);
            break;
        case 48:
            val_string = (char *)value;
            SetSntpTimeZoneStr(val_string);
            break;
        case 49:
            enable_old_sntp = sSettings.sSNTP.sntpEnable;
            val_string = (char *)value;
            SetSntpStateStr(val_string);
            if (sSettings.sSNTP.sntpEnable != enable_old_sntp) {
                SETTINGS_Save();
                log_event_data(LOG_SETTING_SAVE, "Администратор (SNMP)");
            }
            break;
        case 50:
            val_string = (char *)value;
            if (strncmp(val_string, sSettings.sSNTP.ip, strlen(val_string)) != 0) {
                SetSntpServerIpStr(val_string);
                SETTINGS_Save();
                log_event_data(LOG_SETTING_SAVE, "Администратор (SNMP)");
                SNTP_Init();
                //vTaskDelay(7000);
                SNTP_Poll();
            }
            break;
        case 51:
            break;
        case 52:
            val_string = (char *)value;
            SetDateStr(val_string);
            break;
        case 53:
            val_string = (char *)value;
            SetTimeStr(val_string);
            break;
        case 54: /* AKBTimeWork */
            break;
        case 55: /* syslogEnable */
            val_string = (char *)value;
            if (val_string[0] == '1') {
                strcpy(val_string, "on");
            } else {
                strcpy(val_string, "off");
            }
            SetSyslogEnable(val_string);
            break;
         case 56: /* syslogServerIP */
            val_string = (char *)value;
            SetSyslogServer(val_string);
            break;
        case 57: /* syslogServerPort */
            val_string = (char *)value;
            SetSyslogPort(val_string);
            break;
        case 58: /* radiusEnable */
            val_string = (char *)value;
            if (val_string[0] == '1') {
                strcpy(val_string, "on");
            } else {
                strcpy(val_string, "off");
            }
            SetRDSEnableStateStr(val_string);
            break;
         case 59: /* radiusServerIP */
            val_string = (char *)value;
            SetRDSIpStr(val_string);
            break;
        case 60: /* radiusServerPort */
            val_string = (char *)value;
            SetRDSPortStr(val_string);
            break;
        case 61: /* radiusServerPWD */
            val_string = (char *)value;
            SetRDSPasswordkStr(val_string);
            break;
        default :
            return SNMP_ERR_GENERROR;
            break;
    };

    if ((oid >= 22 && oid <= 26)
        || (oid >= 28 && oid <= 61)) {
        SETTINGS_Save();
        log_event_data(LOG_SETTING_SAVE, "Администратор (SNMP)");
    }

    return SNMP_ERR_NOERROR;
}

static snmp_err_t signal_set_test(struct snmp_node_instance *instance, u16_t len, void *value)
{
    snmp_err_t ret = SNMP_ERR_WRONGVALUE;
    char *val_string;
    int32_t val;
    float tmp_value;
    uint8_t j;
    u32_t oid = instance->node->oid; // id сигнала
    bool fail = false;

    switch (oid) {
        case 2:
        case 3:
            if ( len == sizeof(s32_t) ) {
                val = *((s32_t *)value);
                if (val == 1) {
                    ret = SNMP_ERR_NOERROR;
                }
            }
            break;
        case 7: /* BatTest */
            val = *((s32_t *)value);
            if ((val >= 0 && val <= 100) || val == 999) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 8: /* Shutdown UPS */
            if ( len <= 3 ) {
                val_string = (char *)value;
                val_string[len] = 0;
                if (atof(val_string) <= 10) {
                    ret = SNMP_ERR_NOERROR;
                }
            }
            break;
        case 22:
        case 23:
        case 24:
        case 25:
        case 26:
        case 50:
        case 56:
        case 59:
            if ( len <= 15 ) {
                val_string = (char *)value;
                val_string[len] = 0;
                if (check_netsettings(val_string, len)) {
                    ret = SNMP_ERR_NOERROR;
                }
            }
            break;
        case 32:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isfloatdigit(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value < sSettings.UPS_Setting.Ucellmax && tmp_value >= MIN_VOLT_CELL_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 33:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isfloatdigit(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value > sSettings.UPS_Setting.Ucellmin && tmp_value <= MAX_VOLT_CELL_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 34:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isfloatdigit(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= AKB_VOLTAGE_MIN_RANGE && tmp_value <= AKB_VOLTAGE_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 35:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isdigit_int(val_string[j])) {
                    return ret;
                }
            }
            val = atoi(val_string);
            if (val >= CAPACITY_MIN_RANGE && val <= CAPACITY_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 36:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isfloatdigit(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= UPS_POWER_MIN_RANGE && tmp_value <= UPS_POWER_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 37:
        case 40:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isdigit_int(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= MAX_VAC_MIN_RANGE && tmp_value <= MAX_VAC_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 38:
        case 41:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isdigit_int(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= MIN_VAC_MIN_RANGE && tmp_value <= MIN_VAC_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 39:
        case 42:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isdigit_int(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= HIST_VAC_MIN_RANGE && tmp_value <= HIST_VAC_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 43:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isdigit_int(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= MAX_TEMP_MIN_RANGE && tmp_value <= MAX_TEMP_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 44:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isdigit_int(val_string[j])) {
                    if (j == 0 && val_string[j] == '-') {
                        continue;
                    } else {
                        return ret;
                    }
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= MIN_TEMP_MIN_RANGE && tmp_value <= MIN_TEMP_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 45:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isfloatdigit(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= HIST_TEMP_MIN_RANGE && tmp_value <= HIST_TEMP_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 46:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isdigit_int(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= MAX_LOAD_MIN_RANGE && tmp_value <= MAX_LOAD_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 47:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isfloatdigit(val_string[j])) {
                    return ret;
                }
            }
            tmp_value = atof(val_string);
            if (tmp_value >= HIST_LOAD_MIN_RANGE && tmp_value <= HIST_LOAD_MAX_RANGE) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
        case 48:
            val_string = (char *)value;
            val_string[len] = 0;
            if (len > 1 && len < 5) {
                bool fail = false;
                if (val_string[0] != '-' && val_string[0] != '+') {
                    fail = true;
                }
                if (!isdigit_int(val_string[1]) && (!isdigit_int(val_string[2]) && val_string[2] != '.')
                    && (!isdigit_int(val_string[3]) && val_string[3] != '.')) {
                    fail = true;
                }
                if (len == 5) {
                    if (!isdigit_int(val_string[4])) {
                        fail = true;
                    }
                }
                if (!fail) {
                    tmp_value = atof(val_string);
                    if (tmp_value >= -12.0 && tmp_value <= 12.0) {
                        ret = SNMP_ERR_NOERROR;
                    }
                }
            }
            break;
        case 49:
        case 55:
        case 58:
            val_string = (char *)value;
            val_string[len] = 0;
            if (len == 1) {
                if (val_string[0] == '0' || val_string[0] == '1') {
                    ret = SNMP_ERR_NOERROR;
                }
            }
            break;
        case 52:
            val_string = (char *)value;
            val_string[len] = 0;
            if (len == 10) {
                for (j = 0; j < len; j++) {
                    if (j != 4 && j != 7) {
                        if (val_string[j] > 0x39 || val_string[j] < 0x30) {
                            fail = true;
                            break;
                        }
                    } else if (j == 4 || j == 7) {
                        if (val_string[j] != '-') {
                            fail = true;
                            break;
                        }
                    }
                }
                if (!fail) {
                    uint16_t temp = 0;
                    temp = 1000 * (val_string[0] - 0x30) + 100 * (val_string[1] - 0x30) + 10 * (val_string[2] - 0x30) + val_string[3] -
                        0x30;
                    if (temp > 2099 || temp < 2000) {
                        fail = true;
                    }
                    temp = 0;
                    temp = 10 * (val_string[5] - 0x30) + (val_string[6] - 0x30);
                    if (temp > 12) {
                        fail = true;
                    }
                    temp = 0;
                    temp = 10 * (val_string[8] - 0x30) + (val_string[9] - 0x30);
                    if (temp > 31) {
                        fail = true;
                    }
                }
                if (!fail) {
                    ret = SNMP_ERR_NOERROR;
                }
            }
            break;
        case 53:
            val_string = (char *)value;
            val_string[len] = 0;
            if (len == 5) {
                for (j = 0; j < len; j++) {
                    if (j != 2) {
                        if (val_string[j] > 0x39 || val_string[j] < 0x30) {
                            fail = true;
                            break;
                        }

                    } else if (j == 2) {
                        if (val_string[j]  != ':') {
                            fail = true;
                            break;
                        }
                    }
                }
                if (!fail) {
                    uint16_t temp = 0;
                    temp = 10 * (val_string[0] - 0x30) + (val_string[1] - 0x30);
                    if (temp > 23) {
                        fail = true;
                    }
                    temp = 0;
                    temp = 10 * (val_string[3] - 0x30) + (val_string[4] - 0x30);
                    if (temp > 59) {
                        fail = true;
                    }
                }
                if (!fail) {
                    ret = SNMP_ERR_NOERROR;
                }
            }
            break;
        case 57:
        case 60:
            val_string = (char *)value;
            val_string[len] = 0;
            for (j = 0; j < len; j ++) {
                if (!isdigit_int(val_string[j])) {
                    return ret;
                }
            }
            val = atoi(val_string);
            if (val >= 0 && val <= 65535) {
                ret = SNMP_ERR_NOERROR;
            }
            break;
         case 61: /* radiusServerPWD */
            val_string = (char *)value;
            val_string[len] = 0;
            if (len >= 17) {
                return ret;
            }
            for (j = 0; j < len; j ++) {
                if (val_string[j] >= 127 || val_string[j] <= 32) {
                    return ret;
                }
            }
            ret = SNMP_ERR_NOERROR;
            break;
    };


    return ret;
}

#endif


